# Security Policy

## Supported Versions

We currently support the latest published version of this project.  
Older versions may not receive security updates unless explicitly stated.

## Reporting a Vulnerability

If you discover a security issue in this project, please do not open a public issue or pull requests, as doing so would make immediately make the problem visible to potentially malicious actors.

Instead, report it privately by emailing:

📬 **info@tanaos.com**

Please include as much detail as possible so we can verify and address the issue quickly.

We appreciate responsible disclosure and will do our best to respond promptly.
